@@ -32,7 +32,6 @@
 #include "na-tray-manager.h"
 #include "na-tray.h"
 #include "fixedtip.h"
-#include "obox.h"
 
 #define NOTIFICATION_AREA_ICON "gnome-panel-notification-area"
 
@@ -96,7 +95,7 @@ help_cb (BonoboUIComponent *uic,
                                     NA_HELP_DOC);
       dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                       primary);
+                                       "%s", primary);
 
       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
                                                 "%s", error->message);
